/*-----------------------------------------------* 
Project  : Government Analytics in LAC
File: 	   Report on survey responses by country		
Author(s): Flavia Sacco
Date: 	   January 5, 2024						
Input  :   All MIS questionnaires data from SurveyCTO
*-----------------------------------------------*/


//Locals for each MIS queationnaire
local education "EDMIS.dta"
local health "HealthMIS.dta"
local tax "TaxesMIS.dta"
local procurement "ProcurementMIS.dta"
local finance "PFMIS.dta"
local human "HRMIS.dta"

//Open the data
use "$input\`human'", clear

//Additional cleanning

*Dropping the example submitted during info session
drop if q7=="flaviasaccoc@gmail.com"
drop if q1==22
drop if q1==5 & q3==""
drop if consent_to_answer==1
drop if q1==7 & q3==""
drop if q1==19 & q3==""
drop if q5=="Government of the Commonwealth of Dominica"
drop if q7=="acorti@onsc.gub.uy"


//Replacing 900 and 998 with missing 
replace q9=. if q9==900 | q9==999
replace q11=. if q11==900 | q11==998
replace q14=. if q14==900 | q14==998
replace q15=. if q15==900 | q15==998
replace q19=. if q19==900 | q19==998
replace q20=. if q20==900 | q20==998
replace q21=. if q21==900 | q21==998
replace q22=. if q22==900 | q22==998
replace q24=. if q24==900 | q24==998
replace q25=. if q25==900 | q25==998
replace q26=. if q26==900 | q26==998
replace q28=. if q28==900 | q28==998


//Labelling multiple choice options
*Dummy for digitized (1=Fully digitized 0=Not fully digitized)
gen fully_digitized=.
replace fully_digitized=1 if q9==3
replace fully_digitized=0 if q9==1 | q9==2


*Agents of government that use data analytics products
label var q12_1 "Non-managerial staff"
label var q12_2 "Managerial staff"
label var q12_3 "Politicians"
label var q12_4 "No agent uses data analytics products to inform decisions"
label var q12_700 "Other"
label var q12_900 "Don't know"
label var q12_998 "Prefer not to respond"

*Dummy (1=Managerial/Non-managerial staff 2= Politicians)

gen agents=.
replace agents=1 if q12_1==1 | q12_2==1
replace agents=2 if q12_3==1 


*Main uses of data analytics products
label var q13_1 "Monitoring"
label var q13_2 "Accountability"
label var q13_3 "Transparency towards citizens"
label var q13_4 "Policy evaluation"
label var q13_5 "Policy design"
label var q13_6 "Data analytics products are not used"
label var q13_700 "Other"
label var q13_900 "Don't know"
label var q13_998 "Prefer not to respond"

//Use analytics dummy (1/5=Yes 6=No)
gen use_analytics=.
replace use_analytics=1 if q13_1==1 | q13_2==1 | q13_3==1 | q13_4==1 | q13_5==1
replace use_analytics=0 if q13_6==1


*Type of data analytics 
label var q16_1 "Descriptive analytics"
label var q16_2 "Diagnostic analytics"
label var q16_3 "Predictive analytics"
label var q16_900 "Don't know"
label var q16_998 "Prefer not to respond"

*Main drivers for collaboration
label var q23_1 "Technical assistance"
label var q23_2 "Data access"
label var q23_3 "Innovations in data analytics"
label var q23_4 "Financial support"
label var q23_6 "There is no strategy to collaborate on data analytics with academics, etc."
label var q23_700 "Other"
label var q23_900 "Don't know"
label var q23_998 "Prefer not to respond"


//Number of agencies that access and use data for each MIS
egen agency_access = rowtotal(q10_1 q10_2 q10_3 q10_4 q10_5 q10_6 q10_7 q10_700)
egen agency_use = rowtotal(q27_1 q27_2 q27_3 q27_4 q27_5 q27_6 q27_7 q27_700)

//Number of types of analytics
egen analytics = rowtotal(q16_1 q16_2 q16_3)

//Number of data elements 

egen elem_have = rowtotal(q17_1 q17_2 q17_3 q17_4 q17_5 q17_6)
egen elem_used = rowtotal(q18_1 q18_2 q18_3 q18_4 q18_5 q18_6)

//Internal consistencies (based on Juan's email)

*RED FLAGS

*Red1 = no MIS but they replied that they use it more than 50% of the time or more often
gen red1 = (q9==1 & (q11==3 | q11==4))

*Red2 = No entity uses data from MIS but they replied the data is used by agencies 25% of the time or more
gen red2 = (q10_8==1 & (q11!=5))

*For red3= q18==1 & q17!=1 for all the options in each variable. 
*Specify the number of choices
local num_choices 6

* Loop through each choice to check consistency
forval i = 1/`num_choices' {
    local q18_var "q18_`i'"
    local q17_var "q17_`i'"
    
    gen red3_`i' = (`q18_var' == 1 & `q17_var' != 1)
}

*Red4 = more data elements are used than the existing data elements

* Count the selected options in Q18 and Q17
gen count_q18 = 0
gen count_q17 = 0

* Loop through each choice to count selected options in Q18 and Q17
forval i = 1/`num_choices' {
    local q18_var "q18_`i'"
    local q17_var "q17_`i'"
    
    * Count selected options in Q18
    replace count_q18 = count_q18 + (`q18_var' == 1)
    
    * Count selected options in Q17
    replace count_q17 = count_q17 + (`q17_var' == 1)
}

gen red4 = count_q18 > count_q17

*YELLOW FLAGS

*Yellow1 = the MIS is partially digitized but is still used more than 50% of the time by different agencies
gen yellow1 = (q9==2 & (q11==3 | q11==4))

*Yellow2 = The MIS data is used more than 50% of the time or more and the main driver for data analytics is ad-hoc
gen yellow2 = ((q11==3 | q11==4) & q14==1)


//Ordering data
order q1 fully_digitized elem_have q24 q25 q28 agency_use q26 q16 elem_used q20 q14 q21 q22 q19 q15 q13 use_analytics agents

//Change this for every country
save "$input\HRMIS_clean.dta", replace
