* import_individualcap_questionnaire.do
*
* 	Imports and aggregates "Capabilities (Capacidades) Questionnaire" (ID: individualcap_questionnaire) data.
*
*	Inputs:  "Capabilities (Capacidades) Questionnaire_WIDE.csv"
*	Outputs: "Capabilities (Capacidades) Questionnaire.dta"
*
*	Output by SurveyCTO January 5, 2024 4:39 PM.

* initialize Stata
clear all
set more off
set mem 100m

cd "C:\Users\WB484435\WBG\Daniel Rogger - Strengthening Research on the Civil Service\Analysis\Regional Report on Analytics in LAC\analysis\data\output\Survey Data\Reproducibility package\Data\input\"

* initialize workflow-specific parameters
*	Set overwrite_old_data to 1 if you use the review and correction
*	workflow and allow un-approving of submissions. If you do this,
*	incoming data will overwrite old data, so you won't want to make
*	changes to data in your local .dta file (such changes can be
*	overwritten with each new import).
local overwrite_old_data 0

* initialize form-specific parameters
local csvfile "Capabilities (Capacidades) Questionnaire_WIDE.csv"
local dtafile "Capabilities (Capacidades) Questionnaire.dta"
local corrfile "Capabilities (Capacidades) Questionnaire_corrections.csv"
local note_fields1 ""
local text_fields1 "deviceid subscriberid text_audit duration caseid q2 q3 q4 q5 q6 q7_comments q7_attachments q8_comments q8_attachments q9_comments q9_attachments q10_comments q10_attachments q11 instanceid"
local date_fields1 "today"
local datetime_fields1 "submissiondate starttime endtime"

disp
disp "Starting import of: `csvfile'"
disp

* import data from primary .csv file
insheet using "`csvfile'", names clear

* drop extra table-list columns
cap drop reserved_name_for_field_*
cap drop generated_table_list_lab*

* continue only if there's at least one row of data to import
if _N>0 {
	* drop note fields (since they don't contain any real data)
	forvalues i = 1/100 {
		if "`note_fields`i''" ~= "" {
			drop `note_fields`i''
		}
	}
	
	* format date and date/time fields
	forvalues i = 1/100 {
		if "`datetime_fields`i''" ~= "" {
			foreach dtvarlist in `datetime_fields`i'' {
				cap unab dtvarlist : `dtvarlist'
				if _rc==0 {
					foreach dtvar in `dtvarlist' {
						tempvar tempdtvar
						rename `dtvar' `tempdtvar'
						gen double `dtvar'=.
						cap replace `dtvar'=clock(`tempdtvar',"MDYhms",2025)
						* automatically try without seconds, just in case
						cap replace `dtvar'=clock(`tempdtvar',"MDYhm",2025) if `dtvar'==. & `tempdtvar'~=""
						format %tc `dtvar'
						drop `tempdtvar'
					}
				}
			}
		}
		if "`date_fields`i''" ~= "" {
			foreach dtvarlist in `date_fields`i'' {
				cap unab dtvarlist : `dtvarlist'
				if _rc==0 {
					foreach dtvar in `dtvarlist' {
						tempvar tempdtvar
						rename `dtvar' `tempdtvar'
						gen double `dtvar'=.
						cap replace `dtvar'=date(`tempdtvar',"MDY",2025)
						format %td `dtvar'
						drop `tempdtvar'
					}
				}
			}
		}
	}

	* ensure that text fields are always imported as strings (with "" for missing values)
	* (note that we treat "calculate" fields as text; you can destring later if you wish)
	tempvar ismissingvar
	quietly: gen `ismissingvar'=.
	forvalues i = 1/100 {
		if "`text_fields`i''" ~= "" {
			foreach svarlist in `text_fields`i'' {
				cap unab svarlist : `svarlist'
				if _rc==0 {
					foreach stringvar in `svarlist' {
						quietly: replace `ismissingvar'=.
						quietly: cap replace `ismissingvar'=1 if `stringvar'==.
						cap tostring `stringvar', format(%100.0g) replace
						cap replace `stringvar'="" if `ismissingvar'==1
					}
				}
			}
		}
	}
	quietly: drop `ismissingvar'


	* consolidate unique ID into "key" variable
	replace key=instanceid if key==""
	drop instanceid


	* label variables
	label variable key "Unique submission ID"
	cap label variable submissiondate "Date/time submitted"
	cap label variable formdef_version "Form version used on device"
	cap label variable review_status "Review status"
	cap label variable review_comments "Comments made during review"
	cap label variable review_corrections "Corrections made during review"


	label variable consent_to_answer "Do you agree to answer this questionnaire?"
	note consent_to_answer: "Do you agree to answer this questionnaire?"
	label define consent_to_answer 1 "No" 2 "Yes"
	label values consent_to_answer consent_to_answer

	label variable q1 "1. Please indicate the country you will be answering questions about"
	note q1: "1. Please indicate the country you will be answering questions about"
	label define q1 1 "Antigua and Barbuda" 2 "Argentina" 3 "Bahamas" 4 "Barbados" 5 "Belize" 6 "Bolivia" 7 "Brazil" 8 "Chile" 9 "Colombia" 10 "Costa Rica" 11 "Cuba" 12 "Dominica" 13 "Dominican Republic" 14 "Ecuador" 15 "El Salvador" 16 "Grenada" 17 "Guatemala" 18 "Guyana" 19 "Haiti" 20 "Honduras" 21 "Jamaica" 22 "Mexico" 23 "Nicaragua" 24 "Panama" 25 "Paraguay" 26 "Peru" 27 "St. Kitts and Nevis" 28 "St. Lucia" 29 "St. Vincent and the Grenadines" 30 "Suriname" 31 "Trinidad and Tobago" 32 "Uruguay" 33 "Venezuela, RB"
	label values q1 q1

	label variable q2 "2. Name"
	note q2: "2. Name"

	label variable q3 "3. Last name"
	note q3: "3. Last name"

	label variable q4 "4. Organization"
	note q4: "4. Organization"

	label variable q5 "5. Position"
	note q5: "5. Position"

	label variable q6 "6. Email"
	note q6: "6. Email"

	label variable q7 "7. Is there a dedicated career track in the government specifically designed for"
	note q7: "7. Is there a dedicated career track in the government specifically designed for data analytics?"
	label define q7 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q7 q7

	label variable q7_comments "In the following space you can provide any information (comments, web-links) tha"
	note q7_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q7_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q7_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q8 "8. Are there assessments in the government (e.g., exams, focus groups, surveys) "
	note q8: "8. Are there assessments in the government (e.g., exams, focus groups, surveys) of the analytical skills of public servants?"
	label define q8 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q8 q8

	label variable q8_comments "In the following space you can provide any information (comments, web-links) tha"
	note q8_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q8_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q8_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q9 "9. Is there training in the government that supports data analytics skills among"
	note q9: "9. Is there training in the government that supports data analytics skills among public servants?"
	label define q9 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q9 q9

	label variable q9_comments "In the following space you can provide any information (comments, web-links) tha"
	note q9_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q9_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q9_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q10 "10. Are there initiatives in the government to strengthen the capacity of public"
	note q10: "10. Are there initiatives in the government to strengthen the capacity of public servants in using data analytics products for decision-making?"
	label define q10 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q10 q10

	label variable q10_comments "In the following space you can provide any information (comments, web-links) tha"
	note q10_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q10_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q10_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q11 "11. Please provide a comprehensive list of the individuals who contributed to an"
	note q11: "11. Please provide a comprehensive list of the individuals who contributed to answering this survey, including name, position and institution in government, and email"

	label variable q12 "12. I/We authorize the World Bank Group to publish my/our responses"
	note q12: "12. I/We authorize the World Bank Group to publish my/our responses"
	label define q12 1 "No" 2 "Yes"
	label values q12 q12






	* append old, previously-imported data (if any)
	cap confirm file "`dtafile'"
	if _rc == 0 {
		* mark all new data before merging with old data
		gen new_data_row=1
		
		* pull in old data
		append using "`dtafile'"
		
		* drop duplicates in favor of old, previously-imported data if overwrite_old_data is 0
		* (alternatively drop in favor of new data if overwrite_old_data is 1)
		sort key
		by key: gen num_for_key = _N
		drop if num_for_key > 1 & ((`overwrite_old_data' == 0 & new_data_row == 1) | (`overwrite_old_data' == 1 & new_data_row ~= 1))
		drop num_for_key

		* drop new-data flag
		drop new_data_row
	}
	
	* save data to Stata format
	save "`dtafile'", replace

	* show codebook and notes
	codebook
	notes list
}

disp
disp "Finished import of: `csvfile'"
disp

* OPTIONAL: LOCALLY-APPLIED STATA CORRECTIONS
*
* Rather than using SurveyCTO's review and correction workflow, the code below can apply a list of corrections
* listed in a local .csv file. Feel free to use, ignore, or delete this code.
*
*   Corrections file path and filename:  Capabilities (Capacidades) Questionnaire_corrections.csv
*
*   Corrections file columns (in order): key, fieldname, value, notes

capture confirm file "`corrfile'"
if _rc==0 {
	disp
	disp "Starting application of corrections in: `corrfile'"
	disp

	* save primary data in memory
	preserve

	* load corrections
	insheet using "`corrfile'", names clear
	
	if _N>0 {
		* number all rows (with +1 offset so that it matches row numbers in Excel)
		gen rownum=_n+1
		
		* drop notes field (for information only)
		drop notes
		
		* make sure that all values are in string format to start
		gen origvalue=value
		tostring value, format(%100.0g) replace
		cap replace value="" if origvalue==.
		drop origvalue
		replace value=trim(value)
		
		* correct field names to match Stata field names (lowercase, drop -'s and .'s)
		replace fieldname=lower(subinstr(subinstr(fieldname,"-","",.),".","",.))
		
		* format date and date/time fields (taking account of possible wildcards for repeat groups)
		forvalues i = 1/100 {
			if "`datetime_fields`i''" ~= "" {
				foreach dtvar in `datetime_fields`i'' {
					* skip fields that aren't yet in the data
					cap unab dtvarignore : `dtvar'
					if _rc==0 {
						gen origvalue=value
						replace value=string(clock(value,"MDYhms",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
						* allow for cases where seconds haven't been specified
						replace value=string(clock(origvalue,"MDYhm",2025),"%25.0g") if strmatch(fieldname,"`dtvar'") & value=="." & origvalue~="."
						drop origvalue
					}
				}
			}
			if "`date_fields`i''" ~= "" {
				foreach dtvar in `date_fields`i'' {
					* skip fields that aren't yet in the data
					cap unab dtvarignore : `dtvar'
					if _rc==0 {
						replace value=string(clock(value,"MDY",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
					}
				}
			}
		}

		* write out a temp file with the commands necessary to apply each correction
		tempfile tempdo
		file open dofile using "`tempdo'", write replace
		local N = _N
		forvalues i = 1/`N' {
			local fieldnameval=fieldname[`i']
			local valueval=value[`i']
			local keyval=key[`i']
			local rownumval=rownum[`i']
			file write dofile `"cap replace `fieldnameval'="`valueval'" if key=="`keyval'""' _n
			file write dofile `"if _rc ~= 0 {"' _n
			if "`valueval'" == "" {
				file write dofile _tab `"cap replace `fieldnameval'=. if key=="`keyval'""' _n
			}
			else {
				file write dofile _tab `"cap replace `fieldnameval'=`valueval' if key=="`keyval'""' _n
			}
			file write dofile _tab `"if _rc ~= 0 {"' _n
			file write dofile _tab _tab `"disp"' _n
			file write dofile _tab _tab `"disp "CAN'T APPLY CORRECTION IN ROW #`rownumval'""' _n
			file write dofile _tab _tab `"disp"' _n
			file write dofile _tab `"}"' _n
			file write dofile `"}"' _n
		}
		file close dofile
	
		* restore primary data
		restore
		
		* execute the .do file to actually apply all corrections
		do "`tempdo'"

		* re-save data
		save "`dtafile'", replace
	}
	else {
		* restore primary data		
		restore
	}

	disp
	disp "Finished applying corrections in: `corrfile'"
	disp
}

save "C:\Users\WB484435\WBG\Daniel Rogger - Strengthening Research on the Civil Service\Analysis\Regional Report on Analytics in LAC\analysis\data\output\Survey Data\Reproducibility package\Data\input\IndCap.dta", replace
