* import_procurement_questionnaire.do
*
* 	Imports and aggregates "Procurement (Contrataciones Públicas) Questionnaire" (ID: procurement_questionnaire) data.
*
*	Inputs:  "Procurement (Contrataciones Públicas) Questionnaire_WIDE.csv"
*	Outputs: "Procurement (Contrataciones Públicas) Questionnaire.dta"
*
*	Output by SurveyCTO January 5, 2024 4:34 PM.

* initialize Stata
clear all
set more off
set mem 100m

* initialize workflow-specific parameters
*	Set overwrite_old_data to 1 if you use the review and correction
*	workflow and allow un-approving of submissions. If you do this,
*	incoming data will overwrite old data, so you won't want to make
*	changes to data in your local .dta file (such changes can be
*	overwritten with each new import).
local overwrite_old_data 0


cd "C:\Users\WB484435\WBG\Daniel Rogger - Strengthening Research on the Civil Service\Analysis\Regional Report on Analytics in LAC\analysis\data\output\Survey Data\Reproducibility package\Data\input\"

* initialize form-specific parameters
local csvfile "Procurement (Contrataciones Públicas) Questionnaire_WIDE.csv"
local dtafile "Procurement (Contrataciones Públicas) Questionnaire.dta"
local corrfile "Procurement (Contrataciones Públicas) Questionnaire_corrections.csv"
local note_fields1 ""
local text_fields1 "deviceid subscriberid text_audit duration caseid q3 q4 q5 q6 q7 q9_comments q9_attachments q10 q12 q13 q13_comments q13_attachments q15_comments q15_attachments q16 q16_comments q16_attachments q17"
local text_fields2 "q17_comments q17_attachments q18 q20_comments q20_attachments q21_comments q21_attachments q22_comments q22_attachments q23 q24_comments q24_attachments q25_comments q25_attachments q26_comments"
local text_fields3 "q26_attachments q27 q27_comments q27_attachments q28_comments q28_attachments q29 instanceid"
local date_fields1 "today"
local datetime_fields1 "submissiondate starttime endtime"

disp
disp "Starting import of: `csvfile'"
disp

* import data from primary .csv file
insheet using "`csvfile'", names clear

* drop extra table-list columns
cap drop reserved_name_for_field_*
cap drop generated_table_list_lab*

* continue only if there's at least one row of data to import
if _N>0 {
	* drop note fields (since they don't contain any real data)
	forvalues i = 1/100 {
		if "`note_fields`i''" ~= "" {
			drop `note_fields`i''
		}
	}
	
	* format date and date/time fields
	forvalues i = 1/100 {
		if "`datetime_fields`i''" ~= "" {
			foreach dtvarlist in `datetime_fields`i'' {
				cap unab dtvarlist : `dtvarlist'
				if _rc==0 {
					foreach dtvar in `dtvarlist' {
						tempvar tempdtvar
						rename `dtvar' `tempdtvar'
						gen double `dtvar'=.
						cap replace `dtvar'=clock(`tempdtvar',"MDYhms",2025)
						* automatically try without seconds, just in case
						cap replace `dtvar'=clock(`tempdtvar',"MDYhm",2025) if `dtvar'==. & `tempdtvar'~=""
						format %tc `dtvar'
						drop `tempdtvar'
					}
				}
			}
		}
		if "`date_fields`i''" ~= "" {
			foreach dtvarlist in `date_fields`i'' {
				cap unab dtvarlist : `dtvarlist'
				if _rc==0 {
					foreach dtvar in `dtvarlist' {
						tempvar tempdtvar
						rename `dtvar' `tempdtvar'
						gen double `dtvar'=.
						cap replace `dtvar'=date(`tempdtvar',"MDY",2025)
						format %td `dtvar'
						drop `tempdtvar'
					}
				}
			}
		}
	}

	* ensure that text fields are always imported as strings (with "" for missing values)
	* (note that we treat "calculate" fields as text; you can destring later if you wish)
	tempvar ismissingvar
	quietly: gen `ismissingvar'=.
	forvalues i = 1/100 {
		if "`text_fields`i''" ~= "" {
			foreach svarlist in `text_fields`i'' {
				cap unab svarlist : `svarlist'
				if _rc==0 {
					foreach stringvar in `svarlist' {
						quietly: replace `ismissingvar'=.
						quietly: cap replace `ismissingvar'=1 if `stringvar'==.
						cap tostring `stringvar', format(%100.0g) replace
						cap replace `stringvar'="" if `ismissingvar'==1
					}
				}
			}
		}
	}
	quietly: drop `ismissingvar'


	* consolidate unique ID into "key" variable
	replace key=instanceid if key==""
	drop instanceid


	* label variables
	label variable key "Unique submission ID"
	cap label variable submissiondate "Date/time submitted"
	cap label variable formdef_version "Form version used on device"
	cap label variable review_status "Review status"
	cap label variable review_comments "Comments made during review"
	cap label variable review_corrections "Corrections made during review"


	label variable consent_to_answer "Do you agree to answer this questionnaire?"
	note consent_to_answer: "Do you agree to answer this questionnaire?"
	label define consent_to_answer 1 "No" 2 "Yes"
	label values consent_to_answer consent_to_answer

	label variable q1 "1. Please indicate the country you will be answering questions about"
	note q1: "1. Please indicate the country you will be answering questions about"
	label define q1 1 "Antigua and Barbuda" 2 "Argentina" 3 "Bahamas" 4 "Barbados" 5 "Belize" 6 "Bolivia" 7 "Brazil" 8 "Chile" 9 "Colombia" 10 "Costa Rica" 11 "Cuba" 12 "Dominica" 13 "Dominican Republic" 14 "Ecuador" 15 "El Salvador" 16 "Grenada" 17 "Guatemala" 18 "Guyana" 19 "Haiti" 20 "Honduras" 21 "Jamaica" 22 "Mexico" 23 "Nicaragua" 24 "Panama" 25 "Paraguay" 26 "Peru" 27 "St. Kitts and Nevis" 28 "St. Lucia" 29 "St. Vincent and the Grenadines" 30 "Suriname" 31 "Trinidad and Tobago" 32 "Uruguay" 33 "Venezuela, RB"
	label values q1 q1

	label variable q2 "2. Please indicate the Management Information System (MIS) you will be answering"
	note q2: "2. Please indicate the Management Information System (MIS) you will be answering questions about"
	label define q2 1 "Human Resources MIS" 2 "Procurement MIS" 3 "Public Financial MIS" 4 "Tax MIS" 5 "Education MIS" 6 "Health MIS"
	label values q2 q2

	label variable q3 "3. Name"
	note q3: "3. Name"

	label variable q4 "4. Last name"
	note q4: "4. Last name"

	label variable q5 "5. Organization"
	note q5: "5. Organization"

	label variable q6 "6. Position"
	note q6: "6. Position"

	label variable q7 "7. Email"
	note q7: "7. Email"

	label variable q8 "8. Is there a Procurement MIS in place in the government?"
	note q8: "8. Is there a Procurement MIS in place in the government?"
	label define q8 1 "No" 2 "Yes"
	label values q8 q8

	label variable q9 "9. Is the Procurement MIS digitized?"
	note q9: "9. Is the Procurement MIS digitized?"
	label define q9 1 "No" 2 "Partially digitized" 3 "Fully digitized" 900 "Don’t know" 999 "Prefer not to respond"
	label values q9 q9

	label variable q9_comments "In the following space you can provide any information (comments, web-links) tha"
	note q9_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q9_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q9_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q10 "10. What type of government entities, if any, use data analytics products on the"
	note q10: "10. What type of government entities, if any, use data analytics products on the Procurement MIS to inform decisions?"

	label variable q11 "11. How often, approximately, does (do) this (these) entity (entities) use data "
	note q11: "11. How often, approximately, does (do) this (these) entity (entities) use data analytics products on the Procurement MIS to inform decisions?"
	label define q11 1 "Up to 25% of the time" 2 "Between 25% and 50% of the time" 3 "More than 50% of the time, but not all the time" 4 "All or nearly all the time" 5 "No entity uses data analytics products to inform decisions" 900 "Don’t know" 998 "Prefer not to respond"
	label values q11 q11

	label variable q12 "12. What agents of government, if any, use data analytics products on the Procur"
	note q12: "12. What agents of government, if any, use data analytics products on the Procurement MIS to inform decisions?"

	label variable q13 "13. What are the main uses of data analytics products on the Procurement MIS?"
	note q13: "13. What are the main uses of data analytics products on the Procurement MIS?"

	label variable q13_comments "In the following space you can provide any information (comments, web-links) tha"
	note q13_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q13_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q13_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q14 "14. What is the main driver for the development of data analytics products on th"
	note q14: "14. What is the main driver for the development of data analytics products on the Procurement MIS?"
	label define q14 1 "Ad-hoc: sporadic analytical products developed in response to ad-hoc requests (e" 2 "Bureaucratic: regular analytical products in response to administrative laws or " 3 "Strategic: continuous analytical products in response to a data-driven analytica" 700 "Other (please specify)" 900 "Don’t know" 998 "Prefer not to respond"
	label values q14 q14

	label variable q15 "15. Are there formal communication channels to disseminate data analytics produc"
	note q15: "15. Are there formal communication channels to disseminate data analytics products on the Procurement MIS within the government?"
	label define q15 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q15 q15

	label variable q15_comments "In the following space you can provide any information (comments, web-links) tha"
	note q15_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q15_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q15_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q16 "16. What best describes the type of data analytics on the Procurement MIS?"
	note q16: "16. What best describes the type of data analytics on the Procurement MIS?"

	label variable q16_comments "In the following space you can provide any information (comments, web-links) tha"
	note q16_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q16_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q16_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q17 "17. Which of the following data element categories are available on the Procurem"
	note q17: "17. Which of the following data element categories are available on the Procurement MIS?"

	label variable q17_comments "In the following space you can provide any information (comments, web-links) tha"
	note q17_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q17_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q17_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q18 "18. Which of the following data element categories are used for producing data a"
	note q18: "18. Which of the following data element categories are used for producing data analytics products on the Procurement MIS?"

	label variable q19 "19. Are data analytics products on the Procurement MIS regularly refined and upd"
	note q19: "19. Are data analytics products on the Procurement MIS regularly refined and updated to answer the demands of decision-makers?"
	label define q19 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q19 q19

	label variable q20 "20. Is there a dedicated unit/team responsible for producing data analytics prod"
	note q20: "20. Is there a dedicated unit/team responsible for producing data analytics products on the Procurement MIS?"
	label define q20 1 "There is no dedicated unit/team (e.g., data analytics produced on an individual " 2 "Centralized unit/team (e.g., a single data analytics unit at the federal level s" 3 "Decentralized unit/team (e.g., data analytics units within entity supporting exc" 900 "Don’t know" 998 "Prefer not to respond"
	label values q20 q20

	label variable q20_comments "In the following space you can provide any information (comments, web-links) tha"
	note q20_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q20_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q20_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q21 "21. Are there internal funding opportunities (for example, calls for proposals) "
	note q21: "21. Are there internal funding opportunities (for example, calls for proposals) to support analytical projects within the government on the Procurement MIS?"
	label define q21 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q21 q21

	label variable q21_comments "In the following space you can provide any information (comments, web-links) tha"
	note q21_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q21_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q21_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q22 "22. Is there a strategy to collaborate on data analytics on the Procurement MIS "
	note q22: "22. Is there a strategy to collaborate on data analytics on the Procurement MIS with academics, non-profits, foundations, or multilateral organizations?"
	label define q22 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q22 q22

	label variable q22_comments "In the following space you can provide any information (comments, web-links) tha"
	note q22_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q22_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q22_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q23 "23. What are the main drivers for collaborating on data analytics on the Procure"
	note q23: "23. What are the main drivers for collaborating on data analytics on the Procurement MIS with academics, non-profits, foundations, or multilateral organizations?"

	label variable q24 "24. Are there systematic data quality controls (e.g., data cleaning, coverage, h"
	note q24: "24. Are there systematic data quality controls (e.g., data cleaning, coverage, harmonization) in place for the Procurement MIS?"
	label define q24 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q24 q24

	label variable q24_comments "In the following space you can provide any information (comments, web-links) tha"
	note q24_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q24_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q24_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q25 "25. Is there a formal and well-documented protocol that regulates access to the "
	note q25: "25. Is there a formal and well-documented protocol that regulates access to the Procurement MIS data within the government?"
	label define q25 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q25 q25

	label variable q25_comments "In the following space you can provide any information (comments, web-links) tha"
	note q25_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q25_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q25_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q26 "26. Is there an engagement metric to measure how often data on the Procurement M"
	note q26: "26. Is there an engagement metric to measure how often data on the Procurement MIS is being accessed by government entities?"
	label define q26 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q26 q26

	label variable q26_comments "In the following space you can provide any information (comments, web-links) tha"
	note q26_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q26_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q26_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q27 "27. What type of government entities, if any, access data on the Procurement MIS"
	note q27: "27. What type of government entities, if any, access data on the Procurement MIS?"

	label variable q27_comments "In the following space you can provide any information (comments, web-links) tha"
	note q27_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q27_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q27_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q28 "28. Is there a data inventory that lists all available data on the Procurement M"
	note q28: "28. Is there a data inventory that lists all available data on the Procurement MIS?"
	label define q28 1 "No" 2 "Yes" 900 "Don’t know" 998 "Prefer not to respond"
	label values q28 q28

	label variable q28_comments "In the following space you can provide any information (comments, web-links) tha"
	note q28_comments: "In the following space you can provide any information (comments, web-links) that you consider relevant to support the answer"

	label variable q28_attachments "Here you can attach documentation (reports, files) to support the answer (suppor"
	note q28_attachments: "Here you can attach documentation (reports, files) to support the answer (supported files: PDF, ZIP, Excel or Word)"

	label variable q29 "29. Please provide a comprehensive list of the individuals who contributed to an"
	note q29: "29. Please provide a comprehensive list of the individuals who contributed to answering the modules on the Procurement MIS, including name, position and institution in government, and email"

	label variable q30 "30. I/We authorize the World Bank Group to publish my/our responses"
	note q30: "30. I/We authorize the World Bank Group to publish my/our responses"
	label define q30 1 "Agree" 2 "Disagree"
	label values q30 q30






	* append old, previously-imported data (if any)
	cap confirm file "`dtafile'"
	if _rc == 0 {
		* mark all new data before merging with old data
		gen new_data_row=1
		
		* pull in old data
		append using "`dtafile'"
		
		* drop duplicates in favor of old, previously-imported data if overwrite_old_data is 0
		* (alternatively drop in favor of new data if overwrite_old_data is 1)
		sort key
		by key: gen num_for_key = _N
		drop if num_for_key > 1 & ((`overwrite_old_data' == 0 & new_data_row == 1) | (`overwrite_old_data' == 1 & new_data_row ~= 1))
		drop num_for_key

		* drop new-data flag
		drop new_data_row
	}
	
	* save data to Stata format
	save "`dtafile'", replace

	* show codebook and notes
	codebook
	notes list
}

disp
disp "Finished import of: `csvfile'"
disp

* OPTIONAL: LOCALLY-APPLIED STATA CORRECTIONS
*
* Rather than using SurveyCTO's review and correction workflow, the code below can apply a list of corrections
* listed in a local .csv file. Feel free to use, ignore, or delete this code.
*
*   Corrections file path and filename:  Procurement (Contrataciones Públicas) Questionnaire_corrections.csv
*
*   Corrections file columns (in order): key, fieldname, value, notes

capture confirm file "`corrfile'"
if _rc==0 {
	disp
	disp "Starting application of corrections in: `corrfile'"
	disp

	* save primary data in memory
	preserve

	* load corrections
	insheet using "`corrfile'", names clear
	
	if _N>0 {
		* number all rows (with +1 offset so that it matches row numbers in Excel)
		gen rownum=_n+1
		
		* drop notes field (for information only)
		drop notes
		
		* make sure that all values are in string format to start
		gen origvalue=value
		tostring value, format(%100.0g) replace
		cap replace value="" if origvalue==.
		drop origvalue
		replace value=trim(value)
		
		* correct field names to match Stata field names (lowercase, drop -'s and .'s)
		replace fieldname=lower(subinstr(subinstr(fieldname,"-","",.),".","",.))
		
		* format date and date/time fields (taking account of possible wildcards for repeat groups)
		forvalues i = 1/100 {
			if "`datetime_fields`i''" ~= "" {
				foreach dtvar in `datetime_fields`i'' {
					* skip fields that aren't yet in the data
					cap unab dtvarignore : `dtvar'
					if _rc==0 {
						gen origvalue=value
						replace value=string(clock(value,"MDYhms",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
						* allow for cases where seconds haven't been specified
						replace value=string(clock(origvalue,"MDYhm",2025),"%25.0g") if strmatch(fieldname,"`dtvar'") & value=="." & origvalue~="."
						drop origvalue
					}
				}
			}
			if "`date_fields`i''" ~= "" {
				foreach dtvar in `date_fields`i'' {
					* skip fields that aren't yet in the data
					cap unab dtvarignore : `dtvar'
					if _rc==0 {
						replace value=string(clock(value,"MDY",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
					}
				}
			}
		}

		* write out a temp file with the commands necessary to apply each correction
		tempfile tempdo
		file open dofile using "`tempdo'", write replace
		local N = _N
		forvalues i = 1/`N' {
			local fieldnameval=fieldname[`i']
			local valueval=value[`i']
			local keyval=key[`i']
			local rownumval=rownum[`i']
			file write dofile `"cap replace `fieldnameval'="`valueval'" if key=="`keyval'""' _n
			file write dofile `"if _rc ~= 0 {"' _n
			if "`valueval'" == "" {
				file write dofile _tab `"cap replace `fieldnameval'=. if key=="`keyval'""' _n
			}
			else {
				file write dofile _tab `"cap replace `fieldnameval'=`valueval' if key=="`keyval'""' _n
			}
			file write dofile _tab `"if _rc ~= 0 {"' _n
			file write dofile _tab _tab `"disp"' _n
			file write dofile _tab _tab `"disp "CAN'T APPLY CORRECTION IN ROW #`rownumval'""' _n
			file write dofile _tab _tab `"disp"' _n
			file write dofile _tab `"}"' _n
			file write dofile `"}"' _n
		}
		file close dofile
	
		* restore primary data
		restore
		
		* execute the .do file to actually apply all corrections
		do "`tempdo'"

		* re-save data
		save "`dtafile'", replace
	}
	else {
		* restore primary data		
		restore
	}

	disp
	disp "Finished applying corrections in: `corrfile'"
	disp
}

save "C:\Users\WB484435\WBG\Daniel Rogger - Strengthening Research on the Civil Service\Analysis\Regional Report on Analytics in LAC\analysis\data\output\Survey Data\Reproducibility package\Data\input\ProcurementMIS.dta", replace
