**Objective: Append all MIS surveys and produce the graphs for the report
**Author   : Flavia Sacco <fsaccocapurro@worldbank.org>
**Date     : 3/13/24

//Install dependencies
*ssc install mrtab 



//Locals for each MIS questionnaire (6-MIS level questionnaries with same questions in each)
local education "EDMIS_clean.dta"
local health "HealthMIS_clean.dta"
local tax "TaxesMIS_clean.dta"
local procurement "ProcurementMIS_clean.dta"
local finance "PFMIS_clean.dta"
local human "HRMIS_clean.dta"


//Local for MIS
local MIS "education health tax procurement finance human"

//Open the data
use "$input\`education'", clear
append using "$input\`health'"
append using "$input\`tax'"
append using "$input\`procurement'"
append using "$input\`finance'"
append using "$input\`human'"

//Dropping if country is missing
drop if q1==.


order q1 q2 q8 fully_digitized elem_have q24 q25 q28 agency_use q26 q16 elem_used q20 q14 q21 q22 q19 q15 q13 use_analytics agents

label var q2 "MIS"
label var q1 "Country"

//////////////////////////////////////////////////////////////////////////////////////////
///////////////////   Graphs in order of appeareance in the report     ///////////////////
//////////////////////////////////////////////////////////////////////////////////////////

//Figure 4.1
*Question Q16
gen descriptive=1 if q16_1==1
gen diagnostics=1 if q16_2==1
gen preditive=1 if q16_3==1

gen mis= q2

label define mis 1 "HRMIS" 2 "ProcurementMIS" 3 "PFMIS" 4 "TaxMIS" 5 "EDMIS" 6 "HealthMIS"
label values mis mis 

mrgraph hbar q16_1-q16_3, width(18) height(20) stat(column) ///
 blabel(total,  format(%9.1f) color(black)) ///
 by(mis, separate title(Type of analytics performed))
 
 graph export "$output/Figure_4.1.png", as(png) replace 

//Figure 4.2 (these values were placed in a figure manually)
*Question Q16 

//Keep these countries that filled 5+ questionnaires:
//Bolivia, Chile, Costa Rica, Dominica, Ecuador, Guatemala, Honduras, Panama, Paraguay, Uruguay
preserve
keep if q1== 6 | q1==25 | q1== 8 | q1== 24 | q1== 32 | q1== 17 | q1== 20 | q1== 10 | q1== 14
table (q1) (q2) (q16)
restore

//Figure 4.3
*Question Q18 

*Labels of the categories vary by MIS(q2) so these will be included manually
mrgraph hbar q18_1-q18_6, sort(1) width(18) height(20) stat(column) ///
 blabel(total,  format(%9.1f) color(black)) ///
 by(q2, separate title(Data elements used for analytics))

graph export "$output/Figure_4.3.png", as(png) replace  

//Figure 4.4
*Question Q13 (aggregated for all countries)
mrgraph hbar q13_1-q13_5, sort(1) width(16) stat(column) ///
 blabel(total,  format(%9.1f) color(black)) ///
 title(Main uses of analytical products)

graph export "$output/Figure_4.4.png", as(png) replace 
 
//Figure 4.5
*Question Q13 (by MIS)
mrgraph hbar q13_1-q13_5, width(16) stat(column) ///
 blabel(total,  format(%9.1f) color(black)) ///
 by(q2, separate title(Main uses of analytical products))

graph export "$output/Figure_4.5.png", as(png) replace  
 
//Figure 4.6
*Question Q14

//Driver of analytics (ad-hoc, bureaucratic or strategic)

bysort q1 q2: gen count = 1
bysort q1 q2: egen total = total(count)
gen percent = (count / total) * 100

gen driver=.
replace driver = 1 if q14==1
replace driver = 2 if q14==2
replace driver = 3 if q14==3

label var driver "Main driver for analytics"
label def driver 1 "Ad-hoc" 2 "Bureaucratic" 3 "Strategic"
label values driver driver

graph bar, over(driver, label(labsize(small))) ///
 blabel(total,  format(%9.1f) color(black)) ///
 by(, title(Main driver of analytics, size(medium))) by(q2)

graph export "$output/Figure_4.6.png", as(png) replace 

//Figure 4.8 (manually merged together the two graphs below)
*Question Q21 (Internal funding)
gen q21_dummy = (q21 == 2)

label variable q21_dummy "Internal funding"
label define q21_dummy 1 "Yes" 0 "No"
label values q21_dummy q21_dummy

graph hbar, over(q21_dummy, label(labsize(small))) ///
 blabel(total,  format(%9.1f) color(black)) ///
 by(, title(`"Are there internal funding opportunities for analytical projects?"', size(medium))) by(q2)
 
graph export "$output/Figure_4.8_1.png", as(png) replace 

* Question Q22 (strategy with academics/organizations)
gen q22_dummy = (q22 == 2)

label variable q22_dummy "Strategy academics"
label define q22_dummy 1 "Yes" 0 "No"
label values q22_dummy q22_dummy

graph hbar, over(q22_dummy, label(labsize(small))) ///
 blabel(total,  format(%9.1f) color(black)) ///
 by(, title(`"Is there a strategy to collaborate with academics/organizations?"', size(medium))) by(q2)

graph export "$output/Figure_4.8_2.png", as(png) replace 


//Figure 4.9 

*Question Q23
mrgraph hbar q23_1-q23_4,  width(16) stat(column) ///
 title("Main drivers of collaboration with academics/organizations")

graph export "$output/Figure_4.9.png", as(png) replace 
 
//Figure 4.10
*Question Q9
label variable fully_digitized "Fully digitized (1=Yes, 0=No)"
label define fully_digitized 1 "Yes" 0 "No"
label values fully_digitized fully_digitized

graph hbar, over(fully_digitized, label(labsize(small))) ///
blabel(total,  format(%9.1f) color(black)) ///
by(, title(`"Is the MIS fully digitized"', size(medium))) by(q2) 
 
graph export "$output/Figure_4.10.png", as(png) replace 
 
//Figure 4.11

//Keep these countries that filled 5+ questionnaires:
//Bolivia, Chile, Costa Rica, Dominica, Ecuador, Guatemala, Honduras, Panama, Paraguay, Uruguay

preserve
keep if q1== 6 | q1==25 | q1== 8 | q1== 24 | q1== 32 | q1== 17 | q1== 20 | q1== 10 | q1== 14

*Question Q9 
table (q1) (q2) (fully_digitized) 
restore 

 
//Figure 4.12
* Question Q25

gen q25_dummy = (q25 == 2)

label variable q25_dummy "Formal access protocols"
label define q25_dummy 1 "Yes" 0 "No"
label values q25_dummy q25_dummy

graph hbar, over(q25_dummy, label(labsize(small))) ///
blabel(total,  format(%9.1f) color(black)) ///
by(, title(`"Are there formal protocols to regulate access to MIS data?"', size(medium))) by(q2)
 
graph export "$output/Figure_4.12.png", as(png) replace 
 
//Figure 4.13

//Keep these countries that filled 5+ questionnaires:
//Bolivia, Chile, Costa Rica, Dominica, Ecuador, Guatemala, Honduras, Panama, Paraguay, Uruguay

preserve
keep if q1== 6 | q1==25 | q1== 8 | q1== 24 | q1== 32 | q1== 17 | q1== 20 | q1== 10 | q1== 14

*Question Q25
table (q1) (q2) (q25_dummy) 
restore  
 
 
//Figure 4.14

*Question Q24
gen q24_dummy = (q24 == 2)

label variable q24_dummy "Systematic quality controls"
label define q24_dummy 1 "Yes" 0 "No"
label values q24_dummy q24_dummy

graph hbar, over(q24_dummy, label(labsize(small))) ///
 blabel(total,  format(%9.1f) color(black)) ///
 by(, title(`"Are there systematic quality controls in the MIS?"', size(medium))) by(q2)

 
graph export "$output/Figure_4.14.png", as(png) replace 
 
 
save "$output\allMIS_data.dta", replace

//Seguir aca

*************************************************************************************
***Bring the Individual Capabilities survey data (7th survey - at the country level)
*************************************************************************************
use "$input/indcap_data_clean.dta", clear


//Figure 4.7 (all these 3 graphs combined into 1)

*Question Q7
gen q7_dummy = (q7 == 2)
replace q7_dummy = 0 if q1==31
replace q7_dummy = 0 if q7==999

label variable q7_dummy "Career track"
label define q7_dummy 1 "Yes" 0 "No"
label values q7_dummy q7_dummy

graph bar, over(q7_dummy) blabel(total,  format(%9.1f) color(black)) ///
 title(`"Is there a career track for data analytics?"')

graph export "$output/Figure_4.7_1.png", as(png) replace  

*Question Q8
gen q8_dummy = (q8 == 2)
replace q8_dummy = 0 if q1==14

label variable q8_dummy "Assessment"
label define q8_dummy 1 "Yes" 0 "No"
label values q8_dummy q8_dummy

graph bar, over(q8_dummy) blabel(total,  format(%9.1f) color(black)) ///
 title(`"Are there assessments of analytical skills?"')

graph export "$output/Figure_4.7_2.png", as(png) replace  
 
 
*Question Q9
gen q9_dummy = (q9 == 2)

label variable q9_dummy "Trainings"
label define q9_dummy 1 "Yes" 0 "No"
label values q9_dummy q9_dummy

graph bar, over(q9_dummy) blabel(total,  format(%9.1f) color(black)) ///
 title(`"Are there trainings related to data analytics?"')


graph export "$output/Figure_4.7_3.png", as(png) replace  

save "$output\indcap_data.dta", replace


//END OF DO FILE